@@ -14,11 +14,11 @@ Test::Dependencies - Ensure that the dependency listing is complete
 
 =head1 VERSION
 
-Version 0.20
+Version 0.22
 
 =cut
 
-our $VERSION = '0.20';
+our $VERSION = '0.22';
 
 =head1 SYNOPSIS
 
@@ -69,7 +69,7 @@ very large project and you don't want to wait for the heavy style
 every time you run "make test," you might want to try the light
 style or look into the overrides below.
 
-Whether a style is specified or not, the style used can be overriden
+Whether a style is specified or not, the style used can be overridden
 by the environment variable TDSTYLE.  This is useful, for example, if
 you want the heavy style to be used normally, but don't want to take
 the time checking dependencies on your smoke test server.
@@ -132,8 +132,9 @@ sub _get_modules_used {
     my ($files) = @_;
     my @modules;
 
+    require Test::Dependencies::Light;
     foreach my $file (sort @$files) {
-        my $ret = get_modules_used_in_file($file);
+        my $ret = Test::Dependencies::Light::get_modules_used_in_file($file);
         if (! defined $ret) {
             die "Could not determine modules used in '$file'";
         }
@@ -266,10 +267,9 @@ sub ok_dependencies {
             next if $mod eq 'perl';
             next if exists $ignores{$mod} ||  $mod =~ $exclude_re;
 
-            my $first_in =
-                Module::CoreList->first_release($mod,
-                                                $req->requirements_for_module($mod));
-            my $verstr = ($mod->VERSION) ? '(' . $mod->VERSION . ')' : '';
+            my $req_version = $req->requirements_for_module($mod);
+            my $first_in = Module::CoreList->first_release($mod, $req_version);
+            my $verstr = ($req_version) ? '(' . $req_version . ')' : '';
             my $corestr = version->parse($first_in)->normal;
             $tb->ok($first_in > $min_perl_ver,
                     "Required core module '$mod'$verstr "
